<?php
class Fleekcode_Admin {

    public static function init() {
        add_action('admin_menu', array(__CLASS__, 'add_menu_page'));
        add_action('admin_init', array(__CLASS__, 'register_settings'));
        add_action('admin_enqueue_scripts', array(__CLASS__, 'enqueue_admin_styles'));
        add_action('admin_enqueue_scripts', array(__CLASS__, 'enqueue_admin_scripts'));
        add_filter('woocommerce_product_data_tabs', array(__CLASS__, 'add_price_history_tab'));
        add_action('woocommerce_product_data_panels', array(__CLASS__, 'add_price_history_panel'));
        add_action('admin_init', array(__CLASS__, 'handle_import_export'));
        
        // Добавляем хуки для баннера с отзывом
        add_action('admin_notices', array(__CLASS__, 'show_review_banner'));
        add_action('wp_ajax_fleekcode_hide_review_banner', array(__CLASS__, 'hide_review_banner'));
    }

    public static function add_menu_page() {
        add_menu_page(
            __('FleekCode - Omnibus Price Tracker', 'fleekcode-omnibus'),
            __('FleekCode - Omnibus Price Tracker', 'fleekcode-omnibus'),
            'manage_options',
            'fleekcode-omnibus-settings',
            array(__CLASS__, 'settings_page'),
            'dashicons-tag',
            56
        );
    }

    public static function register_settings() {
        $settings = array(
            'fleekcode_omnibus_text' => array(
                'sanitize_callback' => 'sanitize_text_field',
                'type'              => 'string',
                'description'       => 'Omnibus text setting'
            ),
            'fleekcode_omnibus_display_location' => array(
                'sanitize_callback' => 'sanitize_text_field',
                'type'              => 'string',
                'description'       => 'Omnibus display location setting'
            ),
            'fleekcode_omnibus_days' => array(
                'sanitize_callback' => 'absint',
                'type'              => 'integer',
                'description'       => 'Omnibus days setting'
            ),
            'fleekcode_omnibus_price_position' => array(
                'sanitize_callback' => 'sanitize_text_field',
                'type'              => 'string',
                'description'       => 'Omnibus price position setting'
            ),
            'fleekcode_omnibus_min_price_display_mode' => array(
                'sanitize_callback' => 'sanitize_text_field',
                'type'              => 'string',
                'description'       => 'Omnibus min price display mode setting'
            ),
            'fleekcode_omnibus_display_method' => array(
                'sanitize_callback' => 'sanitize_text_field',
                'type'              => 'string',
                'description'       => 'Omnibus display method setting'
            )
        );

        foreach ($settings as $option_name => $args) {
            // phpcs:ignore PluginCheck.CodeAnalysis.SettingSanitization.register_settingDynamic
            register_setting('fleekcode_omnibus_settings_group', $option_name, $args);
        }
    }

    public static function settings_page() {
        if (!current_user_can('manage_options')) {
            wp_die(esc_html__('You do not have sufficient permissions to access this page.', 'fleekcode-omnibus'));
        }
        include FLEEKCODE_OMNIBUS_PLUGIN_DIR . 'admin/views/settings-page.php';
    }

    public static function enqueue_admin_styles() {
        $css_path = FLEEKCODE_OMNIBUS_PLUGIN_DIR . 'assets/css/admin.css';
        if (file_exists($css_path)) {
            wp_enqueue_style(
                'fleekcode-omnibus-admin',
                FLEEKCODE_OMNIBUS_PLUGIN_URL . 'assets/css/admin.css',
                [],
                FLEEKCODE_OMNIBUS_VERSION
            );
        }
    }
	
    public static function enqueue_admin_scripts() {
        wp_enqueue_script(
            'fleekcode-omnibus-admin',
            FLEEKCODE_OMNIBUS_PLUGIN_URL . 'assets/js/admin.js',
            ['jquery'],
            FLEEKCODE_OMNIBUS_VERSION,
            true
        );

        wp_localize_script(
            'fleekcode-omnibus-admin',
            'fleekcode_omnibus_vars', 
            array(
                'nonce' => wp_create_nonce('omnibus_bulk_action'), 
                'ajaxurl' => admin_url('admin-ajax.php'), 
            )
        );
    }

    public static function add_price_history_tab($tabs) {
        $tabs['fleekcode_price_history'] = array(
            'label'  => __('Price History', 'fleekcode-omnibus'),
            'target' => 'fleekcode_price_history_panel',
            'class'  => array(),
        );
        return $tabs;
    }

    public static function add_price_history_panel() {
        global $post, $wpdb;
        $product_id = $post->ID;
        $table_name = $wpdb->prefix . 'fleekcode_omnibus_prices';
        $table_name = esc_sql($table_name);

        $cache_key = 'fleekcode_price_history_' . $product_id;
        $history = wp_cache_get($cache_key, 'fleekcode_admin');

        if (false === $history) {
            // phpcs:ignore WordPress.DB.PreparedSQL.InterpolatedNotPrepared
            $history = $wpdb->get_results(
                $wpdb->prepare(
                    "SELECT id, regular_price, sale_price, date, is_active FROM $table_name WHERE product_id = %d ORDER BY date DESC",
                    $product_id
                ),
                ARRAY_A
            );
            $history = apply_filters('fleekcode_omnibus_price_history', $history, $product_id);
            wp_cache_set($cache_key, $history, 'fleekcode_admin', 3600);
        }

        include FLEEKCODE_OMNIBUS_PLUGIN_DIR . 'admin/views/history-panel.php';
    }
	
    public static function handle_import_export() {
        if (isset($_GET['page']) && $_GET['page'] === 'fleekcode-omnibus-settings' && isset($_GET['action']) && $_GET['action'] === 'export') {
            if (!current_user_can('manage_options')) {
                wp_die('Insufficient permissions');
            }

            global $wpdb;
            $table_name = $wpdb->prefix . 'fleekcode_omnibus_prices';
            $table_name = esc_sql($table_name);
            $data = $wpdb->get_results("SELECT * FROM `$table_name`", ARRAY_A);

            header('Content-Type: application/json');
            header('Content-Disposition: attachment; filename="omnibus_price_history.json"');
            echo json_encode($data);
            exit;
        }

        if (isset($_POST['import_submit']) && current_user_can('manage_options')) {
            if (isset($_FILES['import_file']) && $_FILES['import_file']['type'] === 'application/json') {
                $data = json_decode(file_get_contents($_FILES['import_file']['tmp_name']), true);
                if (is_array($data)) {
                    global $wpdb;
                    $table_name = $wpdb->prefix . 'fleekcode_omnibus_prices';
                    $table_name = esc_sql($table_name);

                    $result = $wpdb->query("TRUNCATE TABLE `$table_name`");
                    if ($result === false) {
                        wp_die('Error: Failed to truncate table - ' . $wpdb->last_error);
                    }

                    foreach ($data as $record) {
                        $wpdb->insert(
                            $table_name,
                            [
                                'product_id' => intval($record['product_id']),
                                'regular_price' => floatval($record['regular_price']),
                                'sale_price' => floatval($record['sale_price']),
                                'date' => sanitize_text_field($record['date']),
                                'is_active' => intval($record['is_active'])
                            ],
                            ['%d', '%f', '%f', '%s', '%d']
                        );
                    }

                    $products = $wpdb->get_col("SELECT DISTINCT product_id FROM `$table_name`");
                    foreach ($products as $product_id) {
                        wp_cache_delete('fleekcode_last_price_' . $product_id);
                        wp_cache_delete('omnibus_price_' . $product_id, 'omnibus');
                        wp_cache_delete('fleekcode_records_' . $product_id);
                        wp_cache_delete('fleekcode_price_history_' . $product_id, 'fleekcode_admin');
                    }

                    wp_redirect(admin_url('admin.php?page=fleekcode-omnibus-settings&imported=1'));
                    exit;
                }
            }
        }
    }

    public static function show_review_banner() {
        global $pagenow;

        if (
            $pagenow === 'index.php' || // Дашборд
            ($pagenow === 'edit.php' && isset($_GET['post_type']) && $_GET['post_type'] === 'product') ||
            (isset($_GET['page']) && $_GET['page'] === 'fleekcode-omnibus-settings') 
        ) {
            $hide_banner = get_user_meta(get_current_user_id(), 'fleekcode_hide_review_banner', true);
            if (!$hide_banner) {
                ?>
                <div class="fleekcode-review-banner notice notice-info">
                    <div class="banner-content">
						<h3><?php echo esc_html__('Do you like FleekCode - Omnibus Price Tracker?', 'fleekcode-omnibus'); ?></h3>
						<p><?php echo esc_html__('If you enjoy our plugin, please leave a review. It helps us grow!', 'fleekcode-omnibus'); ?></p>
						<a href="https://wordpress.org/support/plugin/fleekcode-omnibus/reviews/#new-post" target="_blank" class="button review-button"><?php echo esc_html__('Leave a Review', 'fleekcode-omnibus'); ?></a>
						<button type="button" class="button hide-banner-button"><?php echo esc_html__('Hide', 'fleekcode-omnibus'); ?></button>
					</div>
                </div>
                <script>
                jQuery(document).ready(function($) {
                    $('.hide-banner-button').on('click', function() {
                        var banner = $(this).closest('.fleekcode-review-banner');
                        banner.slideUp(300, function() {
                            banner.remove();
                        });

                        $.post(ajaxurl, {
                            action: 'fleekcode_hide_review_banner',
                            nonce: '<?php echo wp_create_nonce('hide_review_banner'); ?>'
                        });
                    });
                });
                </script>
                <?php
            }
        }
    }

    public static function hide_review_banner() {
        check_ajax_referer('hide_review_banner', 'nonce');
        update_user_meta(get_current_user_id(), 'fleekcode_hide_review_banner', 1);
        wp_send_json_success();
    }
}