<?php
/**
 * Price history panel template
 *
 * @package Fleekcode_Omnibus
 */
if (!defined('ABSPATH')) {
    exit;
}

global $post, $wpdb;
?>
<div id="fleekcode_price_history_panel" class="panel woocommerce_options_panel hidden" data-product-id="<?php global $post; echo esc_attr($post->ID); ?>">
    <div class="options_group">
        <?php wp_nonce_field('omnibus_checkboxes', 'omnibus_nonce'); ?>
        <?php if (empty($history)) : ?>
            <div class="inline notice woocommerce-message">
                <p><?php esc_html_e('Price history is empty.', 'fleekcode-omnibus'); ?></p>
            </div>
        <?php else : ?>
            <p><strong><?php esc_html_e('History of price changes:', 'fleekcode-omnibus'); ?></strong></p>
            <table class="widefat woocommerce_price_history_table">
                <thead>
                <tr>
                    <th><input type="checkbox" id="select-all" /></th>
                    <th><?php esc_html_e('Date', 'fleekcode-omnibus'); ?></th>
                    <th><?php esc_html_e('Regular price', 'fleekcode-omnibus'); ?></th>
                    <th><?php esc_html_e('Sale price', 'fleekcode-omnibus'); ?></th>
                    <th><?php esc_html_e('Display', 'fleekcode-omnibus'); ?></th>
                </tr>
                </thead>
                <tbody>
                <?php foreach ($history as $record) : ?>
                    <?php
                    $date = date_i18n('d.m.Y H:i', strtotime($record['date']));
                    $regular_price = wc_price($record['regular_price']);
                    $sale_price = $record['sale_price'] > 0 ? wc_price($record['sale_price']) : '—';
                    $is_active_checked = $record['is_active'] ? 'checked' : '';
                    ?>
                    <tr>
                        <td><input type="checkbox" class="select-record" value="<?php echo esc_attr($record['id']); ?>" /></td>
                        <td><?php echo esc_html($date); ?></td>
                        <td><?php echo wp_kses_post($regular_price); ?></td>
                        <td><?php echo wp_kses_post($sale_price); ?></td>
                        <td>
                            <input type="checkbox" name="fleekcode_omnibus_is_active[<?php echo esc_attr($record['id']); ?>]" value="1" <?php echo esc_attr($is_active_checked); ?>>
                        </td>
                    </tr>
                <?php endforeach; ?>
                </tbody>
            </table>
            <div class="bulk-actions">
                <select id="bulk-action">
                    <option value="activate"><?php esc_html_e('Activate Selected', 'fleekcode-omnibus'); ?></option>
                    <option value="deactivate"><?php esc_html_e('Deactivate Selected', 'fleekcode-omnibus'); ?></option>
                </select>
                <button type="button" id="apply-bulk-action" class="button"><?php esc_html_e('Apply', 'fleekcode-omnibus'); ?></button>
            </div>
        <?php endif; ?>
    </div>
</div>