<?php
/**
 * Settings page template
 *
 * @package Fleekcode_Omnibus
 */
if (!defined('ABSPATH')) {
    exit;
}
?>
<div class="wrap fleekcode-omnibus-settings">
    <h1><?php esc_html_e('Omnibus Price Tracker Settings', 'fleekcode-omnibus'); ?></h1>
    <form method="post" action="options.php">
        <?php settings_fields('fleekcode_omnibus_settings_group'); ?>
        <table class="form-table">
            <tr valign="top">
                <th scope="row"><?php esc_html_e('Price display text', 'fleekcode-omnibus'); ?></th>
                <td>
                    <input type="text" name="fleekcode_omnibus_text" value="<?php
                    /* translators: %d: Number of days, %price%: Price value */
                    echo esc_attr(get_option('fleekcode_omnibus_text', __('Minimum price over %d days: %price%', 'fleekcode-omnibus')));
                    ?>" class="regular-text" />
                    <p class="description"><?php
                        /* translators: %price% represents the price value, %d represents the number of days */
                        esc_html_e('Use %price% for price and %d for days', 'fleekcode-omnibus');
                        ?></p>
                </td>
            </tr>
            <tr valign="top">
                <th scope="row"><?php esc_html_e('Display location', 'fleekcode-omnibus'); ?></th>
                <td>
                    <select name="fleekcode_omnibus_display_location">
                        <option value="both" <?php selected(get_option('fleekcode_omnibus_display_location'), 'both'); ?>><?php esc_html_e('Product page and catalog', 'fleekcode-omnibus'); ?></option>
                        <option value="product" <?php selected(get_option('fleekcode_omnibus_display_location'), 'product'); ?>><?php esc_html_e('Product page only', 'fleekcode-omnibus'); ?></option>
                        <option value="catalog" <?php selected(get_option('fleekcode_omnibus_display_location'), 'catalog'); ?>><?php esc_html_e('Catalog only', 'fleekcode-omnibus'); ?></option>
                    </select>
                </td>
            </tr>
            <tr valign="top">
                <th scope="row"><?php esc_html_e('Place for text output', 'fleekcode-omnibus'); ?></th>
                <td>
                    <select name="fleekcode_omnibus_price_position">
                        <option value="before" <?php selected(get_option('fleekcode_omnibus_price_position'), 'before'); ?>><?php esc_html_e('Before standard price', 'fleekcode-omnibus'); ?></option>
                        <option value="after" <?php selected(get_option('fleekcode_omnibus_price_position'), 'after'); ?>><?php esc_html_e('After standard price', 'fleekcode-omnibus'); ?></option>
                        <option value="after" <?php selected(get_option('fleekcode_omnibus_price_position'), 'after'); ?>><?php esc_html_e('After standard price', 'fleekcode-omnibus'); ?></option>
                    </select>
                    <p class="description"><?php esc_html_e('Select where to display the minimum price relative to the standard price', 'fleekcode-omnibus'); ?></p>
                </td>
            </tr>
            <tr valign="top">
                <th scope="row"><?php esc_html_e('Number of days to track prices', 'fleekcode-omnibus'); ?></th>
                <td>
                    <input type="number" name="fleekcode_omnibus_days" value="<?php echo esc_attr(get_option('fleekcode_omnibus_days', 30)); ?>" class="small-text" min="1" />
                    <p class="description"><?php esc_html_e('Specify how many days the price should be considered valid', 'fleekcode-omnibus'); ?></p>
                </td>
            </tr>
            <tr valign="top">
                <th scope="row"><?php esc_html_e('Minimum price output', 'fleekcode-omnibus'); ?></th>
                <td>
                    <select name="fleekcode_omnibus_min_price_display_mode">
                        <option value="always" <?php selected(get_option('fleekcode_omnibus_min_price_display_mode'), 'always'); ?>><?php esc_html_e('Always', 'fleekcode-omnibus'); ?></option>
                        <option value="sale" <?php selected(get_option('fleekcode_omnibus_min_price_display_mode'), 'sale'); ?>><?php esc_html_e('Only when the product is on sale', 'fleekcode-omnibus'); ?></option>
                    </select>
                    <p class="description"><?php esc_html_e('Select when to display the minimum price', 'fleekcode-omnibus'); ?></p>
                </td>
            </tr>
            <tr valign="top">
                <th scope="row"><?php esc_html_e('Display method', 'fleekcode-omnibus'); ?></th>
                <td>
                    <select name="fleekcode_omnibus_display_method">
                        <option value="default" <?php selected(get_option('fleekcode_omnibus_display_method'), 'default'); ?>><?php esc_html_e('Default (automatic)', 'fleekcode-omnibus'); ?></option>
                        <option value="shortcode" <?php selected(get_option('fleekcode_omnibus_display_method'), 'shortcode'); ?>><?php esc_html_e('Shortcode only', 'fleekcode-omnibus'); ?></option>
                    </select>
                    <p class="description"><?php esc_html_e('Choose how to display the minimum price: automatically with the product price or via the [fleekcode_omnibus_price] shortcode', 'fleekcode-omnibus'); ?></p>
                </td>
            </tr>
        </table>
        <?php submit_button(); ?>
    </form>
	
	<h2><?php esc_html_e('Import/Export Price History', 'fleekcode-omnibus'); ?></h2>
    <p>
        <a href="<?php echo admin_url('admin.php?page=fleekcode-omnibus-settings&action=export'); ?>" class="button"><?php esc_html_e('Export Price History', 'fleekcode-omnibus'); ?></a>
        <button type="button" id="import-price-history" class="button"><?php esc_html_e('Import Price History', 'fleekcode-omnibus'); ?></button>
    </p>
    <div id="import-form" style="display:none;">
        <form method="post" enctype="multipart/form-data">
            <input type="file" name="import_file" accept=".json" />
            <input type="submit" name="import_submit" value="<?php esc_html_e('Import', 'fleekcode-omnibus'); ?>" class="button" />
        </form>
    </div>
</div>

<script>
jQuery('#import-price-history').on('click', function() {
    jQuery('#import-form').toggle();
});
</script>