<?php
class Fleekcode_Activator {

    public static function activate() {
        global $wpdb;

        $table_name = $wpdb->prefix . 'fleekcode_omnibus_prices';
        $table_name = esc_sql($table_name);

        // phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching
        $table_exists = $wpdb->get_var(
            $wpdb->prepare(
                "SHOW TABLES LIKE %s",
                $table_name
            )
        );

        if (!$table_exists) {
            Fleekcode_Database::create_table();
            if ($wpdb->last_error) {
                if (defined('WP_DEBUG') && WP_DEBUG) {
                    error_log('Fleekcode Omnibus: Table creation failed during activation - ' . $wpdb->last_error);
                }
            } else {
                self::record_initial_prices();
            }
        }
    }

    public static function record_initial_prices() {
        global $wpdb;

        $table_name = $wpdb->prefix . 'fleekcode_omnibus_prices';
        $table_name = esc_sql($table_name);

        $products = get_posts(array(
            'post_type' => 'product',
            'numberposts' => -1,
            'post_status' => 'publish'
        ));

        foreach ($products as $product_post) {
            $product = wc_get_product($product_post->ID);
            if (!$product) continue;

            $product_id = $product->get_id();
            $regular_price = (float) $product->get_regular_price();
            $sale_price = (float) $product->get_sale_price();
            $date = current_time('mysql');

            $initial_sale_price = $product->is_on_sale() && $sale_price > 0 ? $regular_price : $sale_price;

            // phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching
            $exists = $wpdb->get_var(
                $wpdb->prepare(
                    "SELECT COUNT(*) FROM `$table_name` WHERE product_id = %d",
                    $product_id
                )
            );

            if (!$exists) {
                // phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching
                $wpdb->insert(
                    $table_name,
                    [
                        'product_id' => $product_id,
                        'regular_price' => $regular_price,
                        'sale_price' => $initial_sale_price,
                        'date' => $date,
                        'is_active' => 1
                    ],
                    ['%d', '%f', '%f', '%s', '%d']
                );
                if ($wpdb->last_error && defined('WP_DEBUG') && WP_DEBUG) {
                    error_log('Fleekcode Omnibus: Failed to insert initial price for product ID ' . $product_id . ' - ' . $wpdb->last_error);
                }
            }
        }
    }
}