<?php
class Fleekcode_Core {
    public static function init() {
        add_filter('woocommerce_get_price_html', array(__CLASS__, 'modify_price_html'), 10, 2);
    }

    /**
     * Modify the price HTML to include the reference price outside the <p class="price"> block
     *
     * @param string $price_html Original price HTML
     * @param WC_Product $product Product object
     * @return string Modified price HTML with reference price
     */
    public static function modify_price_html($price_html, $product) {
        if (is_admin()) {
            return $price_html;
        }

        $display_method = get_option('fleekcode_omnibus_display_method', 'default');

        if ('shortcode' === $display_method) {
            return $price_html;
        }

        $display_location = get_option('fleekcode_omnibus_display_location', 'both');
        $price_position = get_option('fleekcode_omnibus_price_position', 'after');
        $days = absint(get_option('fleekcode_omnibus_days', 30));
        $min_price_display_mode = get_option('fleekcode_omnibus_min_price_display_mode', 'always');

        if (('product' === $display_location && !is_product()) ||
            ('catalog' === $display_location && is_product())) {
            return $price_html;
        }

        if ('sale' === $min_price_display_mode && !$product->is_on_sale()) {
            return $price_html;
        }

        $reference_price = Fleekcode_Database::get_reference_price($product);
        if (false === $reference_price || $reference_price <= 0) {
            return $price_html;
        }

        /* translators: %d: Number of days, %price%: Price value */
        $text_template = get_option('fleekcode_omnibus_text', __('Minimum price over %d days: %price%', 'fleekcode-omnibus'));
        $custom_text = str_replace(
            array('%d', '%price%'),
            array($days, wc_price($reference_price)),
            $text_template
        );

        $output = '<div class="fleekcode-omnibus-price-container">';
        if ('before' === $price_position) {
            $output .= '<div class="fleekcode-omnibus-price-wrapper fleekcode-before-price">' . wp_kses_post($custom_text) . '</div>';
            $output .= '<div class="fleekcode-standard-price-wrapper">' . $price_html . '</div>';
        } else {
            $output .= '<div class="fleekcode-standard-price-wrapper">' . $price_html . '</div>';
            $output .= '<div class="fleekcode-omnibus-price-wrapper fleekcode-after-price">' . wp_kses_post($custom_text) . '</div>';
        }
        $output .= '</div>';

        return $output;
    }
}